@@ -1,15 +1,18 @@
 import copy
+from typing import Union
 
 from ._data_map_helpers import _get_dependencies
+from ._datamap import DataJetMap
 from ._normalization import _normalize_data_map
 from ._validations import (
     _is_valid_normalized_data_map,
     _normalized_data_map_validation_error,
 )
 from .exceptions import RuntimeResolutionException
+from .keywords import IN, F
 
 
-def execute(data_map: dict, fields: list, context: dict = None) -> dict:
+def execute(data_map: Union[dict, DataJetMap], fields: list, context: dict = None) -> dict:
     """Execute the resolvers in a data_map to return values for `fields` requested.
 
     Args:
@@ -18,6 +21,10 @@ def execute(data_map: dict, fields: list, context: dict = None) -> dict:
         context: A dict of values to send to the data map as context.
 
     """
+
+    if isinstance(data_map, DataJetMap):
+        data_map = data_map.data_map
+
     if context is not None:
         data_map = copy.copy(data_map)
         data_map.update(context)
@@ -39,9 +46,9 @@ def execute(data_map: dict, fields: list, context: dict = None) -> dict:
                 if dependency in results:
                     continue
                 for d in data_map[dependency]:
-                    inputs = d["in"]
+                    inputs = d[IN]
                     if all(input_ in results for input_ in inputs):
-                        f = d["f"]
+                        f = d[F]
                         try:
                             result = f(*[results[in_] for in_ in inputs])
                         except RuntimeResolutionException:
